@@ -36,7 +36,6 @@ Several utility functions exist. Important ones are:
 
 """
 
-from six import string_types
 from ._tables import (Table,
                       _default_ms,
                       _default_ms_subtable,
@@ -45,8 +44,6 @@ from ._tables import (Table,
 
 from .tablehelper import (_add_prefix, _remove_prefix, _do_remove_prefix,
                           _format_row)
-import six
-
 
 def default_ms(name, tabdesc=None, dminfo=None):
     """
@@ -342,7 +339,7 @@ class table(Table):
             #  - concatenate open tables (ConcatTable)
             tabname = _remove_prefix(tablename)
             lockopt = lockoptions
-            if isinstance(lockoptions, string_types):
+            if isinstance(lockoptions, str):
                 lockopt = {'option': lockoptions}
             if isinstance(tabledesc, dict):
                 # Create a new table.
@@ -352,11 +349,11 @@ class table(Table):
                 Table.__init__(self, tabname, lockopt, endian,
                                memtype, nrow, tabledesc, dminfo)
                 if ack:
-                    six.print_('Successful creation of',
-                               lockopt['option'] + '-locked table',
-                               tabname + ':',
-                               self.ncols(), 'columns,',
-                               self.nrows(), 'rows')
+                    print('Successful creation of',
+                          lockopt['option'] + '-locked table',
+                          tabname + ':',
+                          self.ncols(), 'columns,',
+                          self.nrows(), 'rows')
             else:
                 # Deal with existing tables.
                 if not tabname:
@@ -369,31 +366,31 @@ class table(Table):
                     opt = 5
                     if _delete:
                         opt = 6
-                if isinstance(tabname, string_types):
+                if isinstance(tabname, str):
                     Table.__init__(self, tabname, lockopt, opt)
                     if ack:
-                        six.print_('Successful', typstr, 'open of',
-                                   lockopt['option'] + '-locked table',
-                                   tabname + ':',
-                                   self.ncols(), 'columns,',
-                                   self.nrows(), 'rows')
-                elif isinstance(tabname[0], string_types):
+                        print('Successful', typstr, 'open of',
+                              lockopt['option'] + '-locked table',
+                              tabname + ':',
+                              self.ncols(), 'columns,',
+                              self.nrows(), 'rows')
+                elif isinstance(tabname[0], str):
                     # Concatenate and open named tables.
                     Table.__init__(self, tabname, concatsubtables,
                                    lockopt, opt)
                     if ack:
-                        six.print_('Successful', typstr, 'open of',
-                                   lockopt['option'] +
-                                   '-locked concatenated tables',
-                                   tabname, ':', self.ncols(), 'columns,',
-                                   self.nrows(), 'rows')
+                        print('Successful', typstr, 'open of',
+                              lockopt['option'] +
+                              '-locked concatenated tables',
+                              tabname, ':', self.ncols(), 'columns,',
+                              self.nrows(), 'rows')
                 else:
                     # Concatenate already open tables.
                     Table.__init__(self, tabname, concatsubtables, 0, 0, 0)
                     if ack:
-                        six.print_('Successful virtual concatenation of',
-                                   len(tabname), 'tables:', self.ncols(),
-                                   'columns,', self.nrows(), 'rows')
+                        print('Successful virtual concatenation of',
+                              len(tabname), 'tables:', self.ncols(),
+                              'columns,', self.nrows(), 'rows')
         # Create a row object for this table.
         self._makerow()
 
@@ -622,7 +619,7 @@ class table(Table):
         msg = self._toascii(asciifile, headerfile, columnnames, sep,
                             precision, usebrackets)
         if len(msg) > 0:
-            six.print_(msg)
+            print(msg)
 
     def rename(self, newtablename):
         """Rename the table.
@@ -1275,7 +1272,7 @@ class table(Table):
         of the struct value of the i-th keyword.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._getfieldnames('', keyword, -1)
         else:
             return self._getfieldnames('', '', keyword)
@@ -1297,7 +1294,7 @@ class table(Table):
         of the struct value of the i-th keyword.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._getfieldnames(columnname, keyword, -1)
         else:
             return self._getfieldnames(columnname, '', keyword)
@@ -1325,7 +1322,7 @@ class table(Table):
         of the i-th keyword.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._getkeyword('', keyword, -1)
         else:
             return self._getkeyword('', '', keyword)
@@ -1336,7 +1333,7 @@ class table(Table):
         It is similar to :func:`getkeyword`.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._getkeyword(columnname, keyword, -1)
         else:
             return self._getkeyword(columnname, '', keyword)
@@ -1364,7 +1361,7 @@ class table(Table):
         keyset = self.getkeywords()
         names = []
         for key, value in keyset.items():
-            if isinstance(value, string_types) and value.find('Table: ') == 0:
+            if isinstance(value, str) and value.find('Table: ') == 0:
                 names.append(_do_remove_prefix(value))
         return names
 
@@ -1400,7 +1397,7 @@ class table(Table):
         val = value
         if isinstance(val, table):
             val = _add_prefix(val.name())
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._putkeyword('', keyword, -1, makesubrecord, val)
         else:
             return self._putkeyword('', '', keyword, makesubrecord, val)
@@ -1414,7 +1411,7 @@ class table(Table):
         val = value
         if isinstance(val, table):
             val = _add_prefix(val.name())
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             return self._putkeyword(columnname, keyword, -1,
                                     makesubrecord, val)
         else:
@@ -1449,7 +1446,7 @@ class table(Table):
         the i-th keyword.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             self._removekeyword('', keyword, -1)
         else:
             self._removekeyword('', '', keyword)
@@ -1460,7 +1457,7 @@ class table(Table):
         It is similar to :func:`removekeyword`.
 
         """
-        if isinstance(keyword, string_types):
+        if isinstance(keyword, str):
             self._removekeyword(columnname, keyword, -1)
         else:
             self._removekeyword(columnname, '', keyword)
@@ -1480,7 +1477,7 @@ class table(Table):
         # as these aren't valid. (See tabledefinehypercolumn)
         hcdefs = tabledesc.get('_define_hypercolumn_', {})
 
-        for c, hcdef in six.iteritems(hcdefs):
+        for c, hcdef in hcdefs.items():
             if "HCcoordnames" in hcdef and len(hcdef["HCcoordnames"]) == 0:
                 del hcdef["HCcoordnames"]
             if "HCidnames" in hcdef and len(hcdef["HCidnames"]) == 0:
@@ -1618,23 +1615,23 @@ class table(Table):
         tables referenced by table keywords.
 
         """
-        six.print_('Table summary:', self.name())
-        six.print_('Shape:', self.ncols(), 'columns by', self.nrows(), 'rows')
-        six.print_('Info:', self.info())
+        print('Table summary:', self.name())
+        print('Shape:', self.ncols(), 'columns by', self.nrows(), 'rows')
+        print('Info:', self.info())
         tkeys = self.getkeywords()
         if (len(tkeys) > 0):
-            six.print_('Table keywords:', tkeys)
+            print('Table keywords:', tkeys)
         columns = self.colnames()
         if (len(columns) > 0):
-            six.print_('Columns:', columns)
+            print('Columns:', columns)
             for column in columns:
                 ckeys = self.getcolkeywords(column)
                 if (len(ckeys) > 0):
-                    six.print_(column, 'keywords:', ckeys)
+                    print(column, 'keywords:', ckeys)
         if (recurse):
             for key, value in tkeys.items():
                 tabname = _remove_prefix(value)
-                six.print_('Summarizing subtable:', tabname)
+                print('Summarizing subtable:', tabname)
                 lt = table(tabname)
                 if (not lt.summary(recurse)):
                     break
@@ -1829,36 +1826,36 @@ class table(Table):
                 waitstr1 = " &"
                 waitstr2 = "background ..."
             if self.iswritable():
-                six.print_("Flushing data and starting casabrowser in the " +
-                           waitstr2)
+                print("Flushing data and starting casabrowser in the " +
+                      waitstr2)
             else:
-                six.print_("Starting casabrowser in the " + waitstr2)
+                print("Starting casabrowser in the " + waitstr2)
             self.flush()
             self.unlock()
             if os.system('test -e ' + self.name() + '/table.dat') == 0:
                 os.system('casabrowser ' + self.name() + waitstr1)
             elif len(tempname) > 0:
-                six.print_("  making a persistent copy in table " + tempname)
+                print("  making a persistent copy in table " + tempname)
                 self.copy(tempname)
                 os.system('casabrowser ' + tempname + waitstr1)
                 if wait:
                     from casacore.tables import tabledelete
-                    six.print_("  finished browsing")
+                    print("  finished browsing")
                     tabledelete(tempname)
 
                 else:
-                    six.print_(" after browsing use tabledelete('" + tempname +
-                               "') to delete the copy")
+                    print(" after browsing use tabledelete('" + tempname +
+                          "') to delete the copy")
             else:
-                six.print_("Cannot browse because the table is in memory only")
-                six.print_("You can browse a (shallow) persistent copy " +
-                           "of the table like: ")
-                six.print_("   t.browse(True, '/tmp/tab1')")
+                print("Cannot browse because the table is in memory only")
+                print("You can browse a (shallow) persistent copy " +
+                      "of the table like: ")
+                print("   t.browse(True, '/tmp/tab1')")
         else:
             try:
                 import wxPython
             except ImportError:
-                six.print_('casabrowser nor wxPython can be found')
+                print('casabrowser nor wxPython can be found')
                 return
             from wxPython.wx import wxPySimpleApp
             import sys
@@ -1915,34 +1912,34 @@ class table(Table):
                     waitstr1 = " &"
                     waitstr2 = "background ..."
                 if self.iswritable():
-                    six.print_("Flushing data and starting casaviewer " +
-                               "in the " + waitstr2)
+                    print("Flushing data and starting casaviewer " +
+                          "in the " + waitstr2)
                 else:
-                    six.print_("Starting casaviewer in the " + waitstr2)
+                    print("Starting casaviewer in the " + waitstr2)
                 self.flush()
                 self.unlock()
                 if os.system('test -e ' + self.name() + '/table.dat') == 0:
                     os.system('casaviewer ' + self.name() + waitstr1)
                     viewed = True
                 elif len(tempname) > 0:
-                    six.print_("  making a persistent copy in table " +
-                               tempname)
+                    print("  making a persistent copy in table " +
+                          tempname)
                     self.copy(tempname)
                     os.system('casaviewer ' + tempname + waitstr1)
                     viewed = True
                     if wait:
                         from casacore.tables import tabledelete
-                        six.print_("  finished viewing")
+                        print("  finished viewing")
                         tabledelete(tempname)
                     else:
-                        six.print_("  after viewing use tabledelete('" +
-                                   tempname + "') to delete the copy")
+                        print("  after viewing use tabledelete('" +
+                              tempname + "') to delete the copy")
                 else:
-                    six.print_("Cannot browse because the table is " +
-                               "in memory only.")
-                    six.print_("You can browse a (shallow) persistent " +
-                               "copy of the table like:")
-                    six.print_("   t.view(True, '/tmp/tab1')")
+                    print("Cannot browse because the table is " +
+                          "in memory only.")
+                    print("You can browse a (shallow) persistent " +
+                          "copy of the table like:")
+                    print("   t.view(True, '/tmp/tab1')")
         # Could not view the table, so browse it.
         if not viewed:
             self.browse(wait, tempname)
